==> gbsite-1.1.0.tar.gz: gbsite/templates/master/master_projadminpage.php <==
<!--- if verified --->
<? if ($access_level == 4){ echo  ?>
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td>
<font face="<?= $font_1 ?>" size="2">
<p>This is the main console for all of your project administration tasks.  You can choose from the following, or scroll down to see them all:</p>
<p align="center"><a href="#projinfo">Project Info</a> | <a href="#tasks">Tasks</a> | <a href="#downloads">Downloads</a> | <a href="#patches">Patches</a> | <a href="#bugs">Bug Tracker</a> | <a href="#cvs">CVS</a> | <a href="#members">Members</a> | <a href="#mail">Mail Lists</a> | <a href="#news">News</a></p>
<? 
if ($join_request > 0) {
?>
<p>Members have requested to join your project! <a href="/project/<?= $project_name ?>/projjoinlist.php">Click here</a> to review them for admission to your development team.</p>
<? } ?>
</font>
<br>
</td>
</tr>
<!-- project info -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="projinfo"><font face="<?= $font_1 ?>" size="2"><b>Project Information</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>Information regarding your project's title and description may be changed <a href="/project/<?= $project_name ?>/projedit.php">here</a>. You may also enter the <a href="/project/<?= $project_name ?>/projversion.php">software version and version history</a> for your project.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- task manager -->
<form method="post" action="/project/<?= $project_name ?>/task/tasklist.php">
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="tasks"><font face="<?= $font_1 ?>" size="2"><b>Task Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>This is the ToDo list for your project. You can specify time estimates, percentage complete, etc - or you can just use it as a list with names attached to particular items.</p></font></td>
</tr>
<tr>
<td>
<font face="<?= $font_1 ?>" size="2"><b>Edit Tasks By:</b></font>&nbsp;
<select name="task_owner">
	<option value="">- Owner -</option>
<? while(list($mr_id,$mr_name) = @each($mr_list)) {	
	echo "<option value=" . $mr_id . ">" . $mr_name ;
	} 
?>
</select>
&nbsp;<font face="<?= $font_1 ?>" size="2"><i>or</i></font>&nbsp;
<select name="task_status">
	<option value="">- Status -</option>
	
<? while(list($st_id,$st_name) = @each($st_list)) {	
	echo "<option value=" . $st_id . ">" . $st_name ;
	} 
?>	
</select>

&nbsp;<input type="submit" value="Edit Task">
</td>
</tr>
</form>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/task/tasklist.php">List all tasks</a></b>&nbsp;|&nbsp;<a href=/project/<?= $project_name ?>/task/taskadd.php><b>Add new task</b></a></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- download manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="downloads"><font face="<?= $font_1 ?>" size="2"><b>Download Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>This is where you can FTP the latest releases (stable and development) of your project.  Any user can download; only you can upload.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/download/newupload.php">Upload Files</a>&nbsp;|&nbsp;<a href="/project/<?= $project_name ?>/download/download.php?branch=stable">View stable branch</a>&nbsp;|&nbsp;<a href="/project/<?= $project_name ?>/download/download.php?branch=devel">View development branch</a></b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- patch manager -->
<form method="post" action="/project/<?= $project_id ?>/patch/patchlist.php">
<tr>
<td bgcolor="<?= $color_4 ?>"><font face="<?= $font_1 ?>" size="2"><b><a name="patches">Patch Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>This application is a storage system for code patches..</p></font></td>
</tr>
<tr>
<td>
<font face="<?= $font_1 ?>" size="2"><b>Display by type:</b></font>&nbsp;
<select name="patch_status">
<? while(list($pt_id,$pt_name) = @each($pt_list)) {	
	echo "<option value=" . $pt_id . ">" . $pt_name ;
	} 
?>
</select>
</td>
</tr>
<tr>
<td>
&nbsp;<font face="<?= $font_1 ?>" size="2"><i>or by</i></font>&nbsp;
<font face="<?= $font_1 ?>" size="2"><b>user:</b></font>&nbsp;<input type="text" name="username">
&nbsp;<input type="submit" value="Display Patch(s)">
</td>
</tr>
</form>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/patch/patchnew.php">Submit New Patch</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- bug manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="bugs"><font face="<?= $font_1 ?>" size="2"><b>Bug Manager</b>&nbsp;(<?= $bug_open ?> open : <?= $bug_close ?>  closed)</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>You can view all bugs, assign them a certain status, even make them into tasks with owners.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/bugs/buglist.php">View All Bugs</a>&nbsp;|&nbsp;<a href="/project/<?= $project_name ?>/bugs/bugadd.php">Add a Bug</a></b></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- cvs manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="cvs"><font face="<?= $font_1 ?>" size="2"><b>CVS</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>Here's a web interface to your CVS tree. You can also access it via command line at:<br><i>:pserver:<?= empty($member_name)?"anonymous":$member_name ?>@www.greatbridge.org:/usr/local/cvsroot/<?= $project_name ?></i></p></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href=/project/<?= $project_name ?>/viewcvs/>View Web CVS</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- members manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="members"><font face="<?= $font_1 ?>" size="2"><b>Members Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>Add members to your project below. Either type in the user name of the member or the first part of the member name and you will be shown a list of all the members that match your entry. Members must first be registered users of GreatBridge.org.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<form method="post" action=/project/<?= $project_name ?>/members/projaddmemberfind.php>
<td>
<font face="<?= $font_1 ?>" size="2"><b>Member Name:</b></font>&nbsp;<input type=text name=newmem_name>&nbsp;<input type="submit" value="Add Member">
</td>
</form>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td>
<font face="<?= $font_1 ?>" size="2"><b>Edit Member:</b><br><br>
<? while(list(,$member) = @each($members)){ ?>
<a href="/project/<?= $project_name ?>/members/projmemberupdate.php?update_member_id=<?= $member["member_id"] ?>"><?= $member["member_name"]?></a>&nbsp;--&nbsp;<?= ucfirst($roles[$member["role_id"]]) ?><br>
<? } ?>
</font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- mail manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="mail"><font face="<?= $font_1 ?>" size="2"><b>Mail Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>Use this tool to create mailing lists using GNU Mailman.  The lists will also be accessible via a Web forum interface.</p></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/maillist/newlist.php">Create Mailing List</a>&nbsp;|&nbsp;<a href="http://www.greatbridge.org/mailman/admin/<?= $project_name ?>">Administer Existing Mailing Lists</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- survey manager removed until module is completed - jb
<tr bgcolor="<?= $color_7 ?>">
<td bgcolor="<?= $color_4 ?>"><a name="surveys"><font face="<?= $font_1 ?>" size="2"><b>Survey Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>Use this tool to create a survey regarding your project. User feedback will be shown in graph format, and will be accessible to the public.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/survey/create.php">Create Survey</a></b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
-->
<!-- news manager -->
<tr bgcolor="<?= $color_7 ?>">
<td bgcolor="<?= $color_4 ?>"><a name="news"><font face="<?= $font_1 ?>" size="2"><b>News Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>This tool will allow you to announce milestones for your project, as well as any other important information. News content will be displayed on your project home page, and potentially the GreatBridge.org <a href="/index.php">home page</a>.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/news/newsinput.php">Add News</a></b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
</table>
<!--- if not verified --->
<? } else { ?>
You do not have permission to access this area, or you have not <a href="/member/memlogin.php">logged in</a>.
<? } ?>

==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_projadminpage.php <==
<!--- if verified --->
<? if ($access_level == 4){ echo  ?>
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td>
<font face="<?= $font_1 ?>" size="2">
<p>This is the main console for all of your project administration tasks.  You can choose from the following, or scroll down to see them all:</p>
<p align="center"><a href="#projinfo">Project Info</a> | <a href="#tasks">Tasks</a> | <a href="#downloads">Downloads</a> | <a href="#patches">Patches</a> | <a href="#bugs">Bug Tracker</a> | <a href="#cvs">CVS</a> | <a href="#members">Members</a> | <a href="#mail">Mail Lists</a> | <a href="#news">News</a> | <a href="#errata">Errata</a></p>
<? 
if ($join_request > 0) {
?>
<p>Members have requested to join your project! <a href="/project/<?= $project_name ?>/projjoinlist.php">Click here</a> to review them for admission to your development team.</p>
<? } ?>
</font>
<br>
</td>
</tr>
<!-- project info -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="projinfo"><font face="<?= $font_1 ?>" size="2"><b>Project Information</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>Information regarding your project's title and description may be changed <a href="/project/<?= $project_name ?>/projedit.php">here</a>. You may also enter the <a href="/project/<?= $project_name ?>/projversion.php">software version and version history</a> for your project.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- task manager -->
<form method="post" action="/project/<?= $project_name ?>/task/tasklist.php">
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="tasks"><font face="<?= $font_1 ?>" size="2"><b>Task Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>This is the ToDo list for your project. You can specify time estimates, percentage complete, etc - or you can just use it as a list with names attached to particular items.</p></font></td>
</tr>
<tr>
<td>
<font face="<?= $font_1 ?>" size="2"><b>Edit Tasks By:</b></font>&nbsp;
<select name="task_owner">
	<option value="">- Owner -</option>
<? while(list($mr_id,$mr_name) = @each($mr_list)) {	
	echo "<option value=" . $mr_id . ">" . $mr_name ;
	} 
?>
</select>
&nbsp;<font face="<?= $font_1 ?>" size="2"><i>or</i></font>&nbsp;
<select name="task_status">
	<option value="">- Status -</option>
	
<? while(list($st_id,$st_name) = @each($st_list)) {	
	echo "<option value=" . $st_id . ">" . $st_name ;
	} 
?>	
</select>

&nbsp;<input type="submit" value="Edit Task">
</td>
</tr>
</form>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/task/tasklist.php">List all tasks</a></b>&nbsp;|&nbsp;<a href=/project/<?= $project_name ?>/task/taskadd.php><b>Add new task</b></a></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- download manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="downloads"><font face="<?= $font_1 ?>" size="2"><b>Download Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>This is where you can FTP the latest releases (stable and development) of your project.  Any user can download; only you can upload.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/download/newupload.php">Upload Files</a>&nbsp;|&nbsp;<a href="/project/<?= $project_name ?>/download/download.php?branch=stable">View stable branch</a>&nbsp;|&nbsp;<a href="/project/<?= $project_name ?>/download/download.php?branch=devel">View development branch</a></b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- patch manager -->
<form method="post" action="/project/<?= $project_id ?>/patch/patchlist.php">
<tr>
<td bgcolor="<?= $color_4 ?>"><font face="<?= $font_1 ?>" size="2"><b><a name="patches">Patch Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>This application is a storage system for code patches..</p></font></td>
</tr>
<tr>
<td>
<font face="<?= $font_1 ?>" size="2"><b>Display by type:</b></font>&nbsp;
<select name="patch_status">
<? while(list($pt_id,$pt_name) = @each($pt_list)) {	
	echo "<option value=" . $pt_id . ">" . $pt_name ;
	} 
?>
</select>
</td>
</tr>
<tr>
<td>
&nbsp;<font face="<?= $font_1 ?>" size="2"><i>or by</i></font>&nbsp;
<font face="<?= $font_1 ?>" size="2"><b>user:</b></font>&nbsp;<input type="text" name="username">
&nbsp;<input type="submit" value="Display Patch(s)">
</td>
</tr>
</form>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/patch/patchnew.php">Submit New Patch</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- bug manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="bugs"><font face="<?= $font_1 ?>" size="2"><b>Bug Manager</b>&nbsp;(<?= $bug_open ?> open : <?= $bug_close ?>  closed)</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>You can view all bugs, assign them a certain status, even make them into tasks with owners.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/bugs/buglist.php">View All Bugs</a>&nbsp;|&nbsp;<a href="/project/<?= $project_name ?>/bugs/bugadd.php">Add a Bug</a></b></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- cvs manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="cvs"><font face="<?= $font_1 ?>" size="2"><b>CVS</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>Here's a web interface to your CVS tree. You can also access it via command line at:<br><i>:pserver:<?= empty($member_name)?"anonymous":$member_name ?>@www.greatbridge.org:/usr/local/cvsroot/<?= $project_name ?></i></p></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href=/project/<?= $project_name ?>/viewcvs/>View Web CVS</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- members manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="members"><font face="<?= $font_1 ?>" size="2"><b>Members Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>Add members to your project below. Either type in the user name of the member or the first part of the member name and you will be shown a list of all the members that match your entry. Members must first be registered users of <?= $official_name ?>.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<form method="post" action=/project/<?= $project_name ?>/members/projaddmemberfind.php>
<td>
<font face="<?= $font_1 ?>" size="2"><b>Member Name:</b></font>&nbsp;<input type=text name=newmem_name>&nbsp;<input type="submit" value="Add Member">
</td>
</form>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td>
<font face="<?= $font_1 ?>" size="2"><b>Edit Member:</b><br><br>
<? while(list(,$member) = @each($members)){ ?>
<a href="/project/<?= $project_name ?>/members/projmemberupdate.php?update_member_id=<?= $member["member_id"] ?>"><?= $member["member_name"]?></a>&nbsp;--&nbsp;<?= ucfirst($roles[$member["role_id"]]) ?><br>
<? } ?>
</font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- mail manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="mail"><font face="<?= $font_1 ?>" size="2"><b>Mail Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>Use this tool to create mailing lists using GNU Mailman.  The lists will also be accessible via a Web forum interface.</p></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/maillist/newlist.php">Create Mailing List</a>&nbsp;|&nbsp;<a href="http://www.greatbridge.org/mailman/admin/<?= $project_name ?>">Administer Existing Mailing Lists</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- survey manager removed until module is completed - jb
<tr bgcolor="<?= $color_7 ?>">
<td bgcolor="<?= $color_4 ?>"><a name="surveys"><font face="<?= $font_1 ?>" size="2"><b>Survey Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>Use this tool to create a survey regarding your project. User feedback will be shown in graph format, and will be accessible to the public.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/survey/create.php">Create Survey</a></b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
-->
<!-- news manager -->
<tr bgcolor="<?= $color_7 ?>">
<td bgcolor="<?= $color_4 ?>"><a name="news"><font face="<?= $font_1 ?>" size="2"><b>News Manager</b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><p>This tool will allow you to announce milestones for your project, as well as any other important information. News content will be displayed on your project home page, and potentially the <?= $official_name ?> <a href="/index.php">home page</a>.</p></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/news/newsinput.php">Add News</a></b></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<!-- errata manager -->
<tr>
<td bgcolor="<?= $color_4 ?>"><a name="errata"><font face="<?= $font_1 ?>" size="2"><b>Errata Manager</b></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><p>Notify users of software changes after your initial release.</p></font></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b><a href="/project/<?= $project_name ?>/projerrataadd.php">Add/Edit Errata</a></b></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
</table>
<!--- if not verified --->
<? } else { ?>
You do not have permission to access this area, or you have not <a href="/member/memlogin.php">logged in</a>.
<? } ?>
